@@ -12,9 +12,17 @@ sub process {
     my $self  = shift;
     my $event = shift;
     my $tmp   = File::Spec->tmpdir() . '/' . Time::HiRes::time() . '.tmp.yml';
+    open TEMP, ">$tmp" or do {
+        logger ("cannot write-open $tmp");
+        return;
+    };
+    print TEMP Dump ($event);
+    close(TEMP);
+    
     my $exec  = $self->label();
     logger ("exec YAML_FILE=$tmp $exec");
     system_execute ("YAML_FILE=$tmp $exec");
+
     unlink $tmp;
 }
 
